@@ -39,16 +39,15 @@ class client:
         self.maxRequestSize = 33554432
         self.minRequestSize = 65536
         self.nbd = nbd.NBD()
+
+        def debug(func, args):
+            """Write NBD debugging messages to logfile instead of
+            stderr"""
+            log.debug("%s: %s", func, args)
+
+        self.nbd.set_debug_callback(debug)
         self.connection = None
 
-        self.printVersion()
-
-    @staticmethod
-    def printVersion() -> None:
-        """Log libnbd, so it is included within the backup logfiles,
-        to know which components are involved."""
-        log.info("libnbd version: %s", nbd.__version__)
-
     def _getBlockInfo(self) -> None:
         """Read maximum request/block size as advertised by the nbd
         server. This is the value which will then be used by default
@@ -57,15 +56,20 @@ class client:
         if maxSize != 0:
             self.maxRequestSize = maxSize
 
-        log.info("Using Maximum Block size supported by NBD server: [%s]", maxSize)
+        log.debug("Block size supported by NBD server: [%s]", maxSize)
 
     def _connect(self) -> nbd.NBD:
         """Setup connection to NBD server endpoint, return
         connection handle
         """
+        if self.cType.tls and not self.nbd.supports_tls():
+            raise exceptions.NbdConnectionError(
+                "Installed python nbd binding is missing required tls features."
+            )
+
         try:
             if self.cType.tls:
-                self.nbd.set_tls(nbd.TLS_ALLOW)
+                self.nbd.set_tls(nbd.TLS_REQUIRE)
             self.nbd.add_meta_context(self._metaContext)
             self.nbd.set_export_name(self._exportName)
             self.nbd.connect_uri(self.cType.uri)
@@ -93,7 +97,7 @@ class client:
                 )
 
             if self.cType.backupSocket and not os.path.exists(self.cType.backupSocket):
-                log.info("Waiting for NBD Server, Retry: %s", retry)
+                log.info("Waiting for NBD Server unix socket, Retry: %s", retry)
                 retry = retry + 1
                 continue
 
@@ -101,7 +105,7 @@ class client:
                 connection = self._connect()
             except exceptions.NbdConnectionError as e:
                 self.nbd = nbd.NBD()
-                log.info("Waiting for NBD Server, Retry: %s [%s]", retry, e)
+                log.info("Waiting for NBD Server connection, Retry: %s [%s]", retry, e)
                 retry = retry + 1
                 continue
 
