@@ -14,6 +14,7 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
+
 import logging
 import socket
 from typing import Tuple, Callable
@@ -42,12 +43,14 @@ class client:
     """Wrapper around paramiko/sftp put and get functions, to be able to
     remote copy files from hypervisor host"""
 
-    def __init__(self, host: str, user: str, mode: Mode = Mode.DOWNLOAD):
+    def __init__(
+        self, host: str, user: str, port: int = 22, mode: Mode = Mode.DOWNLOAD
+    ):
         self.client = None
         self.host = host
         self.user = user
-        self.copy = Callable[[str, str], None]
-        self.copy = self.copyFrom
+        self.port = port
+        self.copy: Callable[[str, str], None] = self.copyFrom
         if mode == Mode.UPLOAD:
             self.copy = self.copyTo
         self.connection = self.connect()
@@ -66,6 +69,7 @@ class client:
             cli.connect(
                 self.host,
                 username=self.user,
+                port=self.port,
                 timeout=5000,
             )
             return cli
@@ -130,9 +134,11 @@ class client:
         log.debug("Executing remote command: [%s]", cmd)
         ret, err, out = self._execute(cmd)
         logerr = ""
+        if ret == 127:
+            raise exceptions.sshError(err)
         if ret != 0:
             log.error(
-                "Executing command failed, return code: [%s] stderr: [%s], stdout: [%s]",
+                "Executing remote command failed, return code: [%s] stderr: [%s], stdout: [%s]",
                 ret,
                 err,
                 out,
